=== modified file 'src/location/providers/dummy/provider.cpp'
--- src/location/providers/dummy/provider.cpp	2017-05-12 07:43:46 +0000
+++ src/location/providers/dummy/provider.cpp	2017-05-17 07:43:56 +0000
@@ -32,6 +32,31 @@
 namespace env = core::posix::this_process::env;
 namespace fs = boost::filesystem;
 
+const std::uint64_t dummy::Configuration::Values::reference_update_period = 10;
+const float dummy::Configuration::Values::reference_latitude = 9.;
+const float dummy::Configuration::Values::reference_longitude = 53.;
+const float dummy::Configuration::Values::reference_altitude = -2.;
+const float dummy::Configuration::Values::reference_velocity = 9.;
+const float dummy::Configuration::Values::reference_heading = 127.;
+const float dummy::Configuration::Values::reference_horizontal_accuracy = 5.;
+const float dummy::Configuration::Values::reference_vertical_accuracy = 5.;
+
+dummy::Configuration::Configuration()
+    : update_period{Values::reference_update_period},
+      reference_position
+      {
+          Position{}
+          .latitude(Values::reference_latitude * units::degrees)
+          .longitude(Values::reference_longitude * units::degrees)
+          .altitude(Values::reference_altitude * units::meters)
+      },
+      reference_velocity{Values::reference_velocity * units::meters_per_second},
+      reference_heading{Values::reference_heading * units::degrees}
+{
+    reference_position.accuracy().horizontal(Values::reference_horizontal_accuracy * units::meters);
+    reference_position.accuracy().vertical(Values::reference_vertical_accuracy * units::meters);
+}
+
 void dummy::Provider::add_to_registry()
 {
     ProviderRegistry::instance().add_provider_for_name("dummy::Provider", [](const util::settings::Source& settings)
@@ -56,23 +81,23 @@
 
     provider_config.update_period = std::chrono::milliseconds
     {
-        settings.get_value<std::uint64_t>(Configuration::Keys::update_period, 500)
+        settings.get_value<std::uint64_t>(Configuration::Keys::update_period, Configuration::Values::reference_update_period)
     };
 
     provider_config.reference_position
-            .latitude(settings.get_value<float>(Configuration::Keys::reference_position_lat, 51.) * location::units::degrees)
-            .longitude(settings.get_value<float>(Configuration::Keys::reference_position_lon,7.) * location::units::degrees);
+            .latitude(settings.get_value<float>(Configuration::Keys::reference_position_lat, Configuration::Values::reference_latitude) * location::units::degrees)
+            .longitude(settings.get_value<float>(Configuration::Keys::reference_position_lon, Configuration::Values::reference_longitude) * location::units::degrees);
     provider_config.reference_position
-            .altitude(settings.get_value<float>(Configuration::Keys::reference_position_alt, 0.) * location::units::meters);
-    provider_config.reference_position.accuracy()
-            .horizontal(settings.get_value<float>(Configuration::Keys::reference_horizontal_accuracy, 0.) * location::units::meters);
-    provider_config.reference_position.accuracy()
-            .vertical(settings.get_value<float>(dummy::Configuration::Keys::reference_vertical_accuracy, 0.) * location::units::meters);
+            .altitude(settings.get_value<float>(Configuration::Keys::reference_position_alt, Configuration::Values::reference_altitude) * location::units::meters);
+    provider_config.reference_position.accuracy()
+            .horizontal(settings.get_value<float>(Configuration::Keys::reference_horizontal_accuracy, Configuration::Values::reference_horizontal_accuracy) * location::units::meters);
+    provider_config.reference_position.accuracy()
+            .vertical(settings.get_value<float>(dummy::Configuration::Keys::reference_vertical_accuracy, Configuration::Values::reference_vertical_accuracy) * location::units::meters);
 
     provider_config.reference_velocity =
-            settings.get_value<float>(Configuration::Keys::reference_velocity, 9.) * location::units::meters_per_second;
+            settings.get_value<float>(Configuration::Keys::reference_velocity, Configuration::Values::reference_velocity) * location::units::meters_per_second;
     provider_config.reference_heading =
-            settings.get_value<float>(Configuration::Keys::reference_heading, 127.) * location::units::degrees;
+            settings.get_value<float>(Configuration::Keys::reference_heading, Configuration::Values::reference_heading) * location::units::degrees;
 
     return location::Provider::Ptr{new dummy::Provider{provider_config}};
 }

=== modified file 'src/location/providers/dummy/provider.h'
--- src/location/providers/dummy/provider.h	2017-05-12 07:43:46 +0000
+++ src/location/providers/dummy/provider.h	2017-05-17 07:43:56 +0000
@@ -70,23 +70,31 @@
         };
     };
 
+    struct Values
+    {
+        static const std::uint64_t reference_update_period;
+        static const float reference_latitude;
+        static const float reference_longitude;
+        static const float reference_altitude;
+        static const float reference_velocity;
+        static const float reference_heading;
+        static const float reference_horizontal_accuracy;
+        static const float reference_vertical_accuracy;
+    };
+
+    Configuration();
+
     // Updates are delivered every update_period milliseconds.
-    std::chrono::milliseconds update_period{10};
+    std::chrono::milliseconds update_period;
 
     // The reference position that is delivered in every upate cycle.
-    Position reference_position{Position{9. * units::degrees, 53. * units::degrees}.altitude(-2 * units::meters)};
+    Position reference_position;
 
     // The reference velocity that is delivered in every update cycle.
-    units::MetersPerSecond reference_velocity
-    {
-        9 * units::meters_per_second
-    };
+    units::MetersPerSecond reference_velocity;
 
     // The reference heading that is delivered in every update cycle.
-    units::Degrees reference_heading
-    {
-        127 * units::degrees
-    };
+    units::Degrees reference_heading;
 };
 
 class Provider : public location::Provider

=== modified file 'src/location/util/settings.h'
--- src/location/util/settings.h	2017-05-15 06:57:54 +0000
+++ src/location/util/settings.h	2017-05-17 07:43:56 +0000
@@ -40,7 +40,7 @@
     explicit Source(const boost::property_tree::ptree& ptree = boost::property_tree::ptree{});
 
     template<typename T>
-    T get_value(const std::string& key, T&& value) const
+    T get_value(const std::string& key, T value) const
     {
         if (auto v = get(key))
         {

